@@ -16,23 +16,16 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-
 #include "updateview_visitors.h"
 
-#include "updateview.h"
 #include "updateview_items.h"
 
-
-using Cervisia::Entry;
-
-
 ApplyFilterVisitor::ApplyFilterVisitor(UpdateView::Filter filter)
     : m_filter(filter)
 {
 }
 
-
-void ApplyFilterVisitor::preVisit(UpdateDirItem* item)
+void ApplyFilterVisitor::preVisit(UpdateDirItem *item)
 {
     // as QTreeWidgetItem::setHidden() is recursive we have to make
     // this UpdateDirItem visible first and later we can make it invisible
@@ -43,53 +36,39 @@ void ApplyFilterVisitor::preVisit(UpdateDirItem* item)
     m_invisibleDirItems.insert(item);
 }
 
-
-void ApplyFilterVisitor::postVisit(UpdateDirItem* item)
+void ApplyFilterVisitor::postVisit(UpdateDirItem *item)
 {
     // a UpdateDirItem is visible if
     // - it has visible children
     // - it is not opened
     // - empty directories are not hidden
     // - it has no parent (top level item)
-    const bool visible(!m_invisibleDirItems.count(item)
-                       || !item->wasScanned()
-                       || !(m_filter & UpdateView::NoEmptyDirectories)
-                       || !item->parent());
+    const bool visible(!m_invisibleDirItems.count(item) || !item->wasScanned() || !(m_filter & UpdateView::NoEmptyDirectories) || !item->parent());
 
     // only set invisible as QTreeWidgetItem::setHidden() is recursive
     // and so maybe overrides the state applied by the filter
-    if (visible)
-    {
+    if (visible) {
         markAllParentsAsVisible(item);
-    }
-    else
-    {
+    } else {
         item->setHidden(true);
     }
 }
 
-
-void ApplyFilterVisitor::visit(UpdateFileItem* item)
+void ApplyFilterVisitor::visit(UpdateFileItem *item)
 {
     const bool visible(item->applyFilter(m_filter));
-    if (visible)
-    {
+    if (visible) {
         markAllParentsAsVisible(item);
     }
 }
 
-
-void ApplyFilterVisitor::markAllParentsAsVisible(UpdateItem* item)
+void ApplyFilterVisitor::markAllParentsAsVisible(UpdateItem *item)
 {
-    while ((item = static_cast<UpdateDirItem*>(item->parent())))
-    {
-        TItemSet::iterator it = m_invisibleDirItems.find(item);
-        if (it != m_invisibleDirItems.end())
-        {
+    while ((item = static_cast<UpdateDirItem *>(item->parent()))) {
+        auto it = m_invisibleDirItems.find(item);
+        if (it != m_invisibleDirItems.end()) {
             m_invisibleDirItems.erase(it);
-        }
-        else
-        {
+        } else {
             // if this item isn't in the map anymore all parents
             // are already removed too
             break;
